From: NTP Release Engineering This document describes the configuration file for the NTP Project’s
This document applies to version 4.3.107 of This document applies to version 4.3.108 of This document describes the symmetric key file for the NTP Project’s
This document applies to version 4.3.107 of This document applies to version 4.3.108 of ntpd program.
ntp.conf.
+ntp.conf.
Short Table of Contents
diff --git a/ntpd/ntp.conf.man.in b/ntpd/ntp.conf.man.in
index 3e5d5ca85b..e892b5f1ea 100644
--- a/ntpd/ntp.conf.man.in
+++ b/ntpd/ntp.conf.man.in
@@ -10,11 +10,11 @@
.ds B-Font B
.ds I-Font I
.ds R-Font R
-.TH ntp.conf 5 "02 Nov 2025" "4.3.107" "File Formats"
+.TH ntp.conf 5 "18 Feb 2026" "4.3.108" "File Formats"
.\"
.\" EDIT THIS FILE WITH CAUTION (in-mem file)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:44:57 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:20 PM by AutoGen 5.18.16
.\" From the definitions ntp.conf.def
.\" and the template file agman-cmd.tpl
.SH NAME
diff --git a/ntpd/ntp.conf.mdoc.in b/ntpd/ntp.conf.mdoc.in
index c49ced58eb..bdb83ba6b8 100644
--- a/ntpd/ntp.conf.mdoc.in
+++ b/ntpd/ntp.conf.mdoc.in
@@ -1,9 +1,9 @@
-.Dd November 2 2025
+.Dd February 18 2026
.Dt NTP_CONF 5 File Formats
.Os
.\" EDIT THIS FILE WITH CAUTION (ntp.mdoc)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:44:44 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:08 PM by AutoGen 5.18.16
.\" From the definitions ntp.conf.def
.\" and the template file agmdoc-cmd.tpl
.Sh NAME
diff --git a/ntpd/ntp.keys.5man b/ntpd/ntp.keys.5man
index dc752a8c0d..926ee73c29 100644
--- a/ntpd/ntp.keys.5man
+++ b/ntpd/ntp.keys.5man
@@ -1,8 +1,8 @@
-.TH ntp.keys 5man "02 Nov 2025" "4.3.107" "File Formats"
+.TH ntp.keys 5man "18 Feb 2026" "4.3.108" "File Formats"
.\"
.\" EDIT THIS FILE WITH CAUTION (ntp.man)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:45:00 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:23 PM by AutoGen 5.18.16
.\" From the definitions ntp.keys.def
.\" and the template file agman-file.tpl
.Sh NAME
diff --git a/ntpd/ntp.keys.5mdoc b/ntpd/ntp.keys.5mdoc
index 165d384167..956b11ade0 100644
--- a/ntpd/ntp.keys.5mdoc
+++ b/ntpd/ntp.keys.5mdoc
@@ -1,9 +1,9 @@
-.Dd November 2 2025
+.Dd February 18 2026
.Dt NTP_KEYS 5mdoc File Formats
.Os FreeBSD 12.1-RELEASE_SI
.\" EDIT THIS FILE WITH CAUTION (ntp.mdoc)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:44:47 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:10 PM by AutoGen 5.18.16
.\" From the definitions ntp.keys.def
.\" and the template file agmdoc-file.tpl
.Sh NAME
diff --git a/ntpd/ntp.keys.html b/ntpd/ntp.keys.html
index 6a51a8c820..d6cdb50edc 100644
--- a/ntpd/ntp.keys.html
+++ b/ntpd/ntp.keys.html
@@ -50,7 +50,7 @@ Next: ntp.keys Desc
ntpd program.
ntp.keys.
+ntp.keys.
Short Table of Contents
diff --git a/ntpd/ntp.keys.man.in b/ntpd/ntp.keys.man.in
index 54d749224d..e0e6e26287 100644
--- a/ntpd/ntp.keys.man.in
+++ b/ntpd/ntp.keys.man.in
@@ -1,8 +1,8 @@
-.TH ntp.keys 5 "02 Nov 2025" "4.3.107" "File Formats"
+.TH ntp.keys 5 "18 Feb 2026" "4.3.108" "File Formats"
.\"
.\" EDIT THIS FILE WITH CAUTION (ntp.man)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:45:00 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:23 PM by AutoGen 5.18.16
.\" From the definitions ntp.keys.def
.\" and the template file agman-file.tpl
.Sh NAME
diff --git a/ntpd/ntp.keys.mdoc.in b/ntpd/ntp.keys.mdoc.in
index f55e41926b..462e6e46b2 100644
--- a/ntpd/ntp.keys.mdoc.in
+++ b/ntpd/ntp.keys.mdoc.in
@@ -1,9 +1,9 @@
-.Dd November 2 2025
+.Dd February 18 2026
.Dt NTP_KEYS 5 File Formats
.Os FreeBSD 12.1-RELEASE_SI
.\" EDIT THIS FILE WITH CAUTION (ntp.mdoc)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:44:47 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:10 PM by AutoGen 5.18.16
.\" From the definitions ntp.keys.def
.\" and the template file agmdoc-file.tpl
.Sh NAME
diff --git a/ntpd/ntpd.man.in b/ntpd/ntpd.man.in
index 8ee0810b67..7879d70706 100644
--- a/ntpd/ntpd.man.in
+++ b/ntpd/ntpd.man.in
@@ -10,11 +10,11 @@
.ds B-Font B
.ds I-Font I
.ds R-Font R
-.TH ntpd @NTPD_MS@ "02 Nov 2025" "4.3.107" "User Commands"
+.TH ntpd @NTPD_MS@ "18 Feb 2026" "4.3.108" "User Commands"
.\"
.\" EDIT THIS FILE WITH CAUTION (in-mem file)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:45:01 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:24 PM by AutoGen 5.18.16
.\" From the definitions ntpd-opts.def
.\" and the template file agman-cmd.tpl
.SH NAME
diff --git a/ntpd/ntpd.mdoc.in b/ntpd/ntpd.mdoc.in
index 465a5e6bc7..cd8442d00f 100644
--- a/ntpd/ntpd.mdoc.in
+++ b/ntpd/ntpd.mdoc.in
@@ -1,9 +1,9 @@
-.Dd November 2 2025
+.Dd February 18 2026
.Dt NTPD @NTPD_MS@ User Commands
.Os
.\" EDIT THIS FILE WITH CAUTION (ntpd-opts.mdoc)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:44:48 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:11 PM by AutoGen 5.18.16
.\" From the definitions ntpd-opts.def
.\" and the template file agmdoc-cmd.tpl
.Sh NAME
diff --git a/ntpdc/invoke-ntpdc.texi b/ntpdc/invoke-ntpdc.texi
index 693abef7fa..d465981e43 100644
--- a/ntpdc/invoke-ntpdc.texi
+++ b/ntpdc/invoke-ntpdc.texi
@@ -6,7 +6,7 @@
#
# EDIT THIS FILE WITH CAUTION (invoke-ntpdc.texi)
#
-# It has been AutoGen-ed November 2, 2025 at 03:45:08 AM by AutoGen 5.18.16
+# It has been AutoGen-ed February 18, 2026 at 03:56:34 PM by AutoGen 5.18.16
# From the definitions ntpdc-opts.def
# and the template file agtexi-cmd.tpl
@end ignore
@@ -77,7 +77,7 @@ with a status code of 0.
@exampleindent 0
@example
-ntpdc - vendor-specific NTPD control program - Ver. 4.3.107
+ntpdc - vendor-specific NTPD control program - Ver. 4.3.108
Usage: ntpdc [ - [] | --[@{=| @}] ]... [ host ...]
Flg Arg Option-Name Description
-4 no ipv4 Force IPv4 DNS name resolution
diff --git a/ntpdc/ntpdc-opts.h b/ntpdc/ntpdc-opts.h
index af7d880739..01aa454c6f 100644
--- a/ntpdc/ntpdc-opts.h
+++ b/ntpdc/ntpdc-opts.h
@@ -1,7 +1,7 @@
/*
* EDIT THIS FILE WITH CAUTION (ntpdc-opts.h)
*
- * It has been AutoGen-ed November 2, 2025 at 03:45:03 AM by AutoGen 5.18.16
+ * It has been AutoGen-ed February 18, 2026 at 03:56:28 PM by AutoGen 5.18.16
* From the definitions ntpdc-opts.def
* and the template file options
*
@@ -92,9 +92,9 @@ typedef enum {
/** count of all options for ntpdc */
#define OPTION_CT 16
/** ntpdc version */
-#define NTPDC_VERSION "4.3.107"
+#define NTPDC_VERSION "4.3.108"
/** Full ntpdc version text */
-#define NTPDC_FULL_VERSION "ntpdc 4.3.107"
+#define NTPDC_FULL_VERSION "ntpdc 4.3.108"
/**
* Interface defines for all options. Replace "n" with the UPPER_CASED
diff --git a/ntpdc/ntpdc.1ntpdcman b/ntpdc/ntpdc.1ntpdcman
index ea2d193256..ef3bde997b 100644
--- a/ntpdc/ntpdc.1ntpdcman
+++ b/ntpdc/ntpdc.1ntpdcman
@@ -10,11 +10,11 @@
.ds B-Font B
.ds I-Font I
.ds R-Font R
-.TH ntpdc 1ntpdcman "02 Nov 2025" "4.3.107" "User Commands"
+.TH ntpdc 1ntpdcman "18 Feb 2026" "4.3.108" "User Commands"
.\"
.\" EDIT THIS FILE WITH CAUTION (in-mem file)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:45:10 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:37 PM by AutoGen 5.18.16
.\" From the definitions ntpdc-opts.def
.\" and the template file agman-cmd.tpl
.SH NAME
diff --git a/ntpdc/ntpdc.1ntpdcmdoc b/ntpdc/ntpdc.1ntpdcmdoc
index bec219a1a2..ccff3cadf7 100644
--- a/ntpdc/ntpdc.1ntpdcmdoc
+++ b/ntpdc/ntpdc.1ntpdcmdoc
@@ -1,9 +1,9 @@
-.Dd November 2 2025
+.Dd February 18 2026
.Dt NTPDC 1ntpdcmdoc User Commands
.Os
.\" EDIT THIS FILE WITH CAUTION (ntpdc-opts.mdoc)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:45:06 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:33 PM by AutoGen 5.18.16
.\" From the definitions ntpdc-opts.def
.\" and the template file agmdoc-cmd.tpl
.Sh NAME
diff --git a/ntpdc/ntpdc.html b/ntpdc/ntpdc.html
index 935d01215b..57d216bb06 100644
--- a/ntpdc/ntpdc.html
+++ b/ntpdc/ntpdc.html
@@ -53,7 +53,7 @@ display the time offset of the system clock relative to the server
clock. Run as root, it can correct the system clock to this offset as
well. It can be run as an interactive command or from a cron job.
-This document applies to version 4.3.107 of ntpdc.
+
This document applies to version 4.3.108 of ntpdc.
The program implements the SNTP protocol as defined by RFC 5905, the NTPv4
IETF specification.
@@ -199,7 +199,7 @@ used to select the program, defaulting to more. Both will exit
with a status code of 0.
-ntpdc - vendor-specific NTPD control program - Ver. 4.3.107
+ntpdc - vendor-specific NTPD control program - Ver. 4.3.108
Usage: ntpdc [ -<flag> [<val>] | --<name>[{=| }<val>] ]... [ host ...]
Flg Arg Option-Name Description
-4 no ipv4 Force IPv4 DNS name resolution
diff --git a/ntpdc/ntpdc.man.in b/ntpdc/ntpdc.man.in
index 0ce21d3f79..ac00390001 100644
--- a/ntpdc/ntpdc.man.in
+++ b/ntpdc/ntpdc.man.in
@@ -10,11 +10,11 @@
.ds B-Font B
.ds I-Font I
.ds R-Font R
-.TH ntpdc @NTPDC_MS@ "02 Nov 2025" "4.3.107" "User Commands"
+.TH ntpdc @NTPDC_MS@ "18 Feb 2026" "4.3.108" "User Commands"
.\"
.\" EDIT THIS FILE WITH CAUTION (in-mem file)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:45:10 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:37 PM by AutoGen 5.18.16
.\" From the definitions ntpdc-opts.def
.\" and the template file agman-cmd.tpl
.SH NAME
diff --git a/ntpdc/ntpdc.mdoc.in b/ntpdc/ntpdc.mdoc.in
index e3777d2869..cba9ef219c 100644
--- a/ntpdc/ntpdc.mdoc.in
+++ b/ntpdc/ntpdc.mdoc.in
@@ -1,9 +1,9 @@
-.Dd November 2 2025
+.Dd February 18 2026
.Dt NTPDC @NTPDC_MS@ User Commands
.Os
.\" EDIT THIS FILE WITH CAUTION (ntpdc-opts.mdoc)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:45:06 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:33 PM by AutoGen 5.18.16
.\" From the definitions ntpdc-opts.def
.\" and the template file agmdoc-cmd.tpl
.Sh NAME
diff --git a/ntpq/invoke-ntpq.texi b/ntpq/invoke-ntpq.texi
index 1587ab625b..cd341eeba4 100644
--- a/ntpq/invoke-ntpq.texi
+++ b/ntpq/invoke-ntpq.texi
@@ -6,7 +6,7 @@
#
# EDIT THIS FILE WITH CAUTION (invoke-ntpq.texi)
#
-# It has been AutoGen-ed November 2, 2025 at 03:45:22 AM by AutoGen 5.18.16
+# It has been AutoGen-ed February 18, 2026 at 03:56:48 PM by AutoGen 5.18.16
# From the definitions ntpq-opts.def
# and the template file agtexi-cmd.tpl
@end ignore
@@ -945,7 +945,7 @@ with a status code of 0.
@exampleindent 0
@example
-ntpq - standard NTP query program - Ver. 4.3.107
+ntpq - standard NTP query program - Ver. 4.3.108
Usage: ntpq [ - [] | --[@{=| @}] ]... [ host ...]
Flg Arg Option-Name Description
-4 no ipv4 Force IPv4 name resolution
diff --git a/ntpq/ntpq-opts.h b/ntpq/ntpq-opts.h
index f0345b8d1b..fce22f3c0e 100644
--- a/ntpq/ntpq-opts.h
+++ b/ntpq/ntpq-opts.h
@@ -1,7 +1,7 @@
/*
* EDIT THIS FILE WITH CAUTION (ntpq-opts.h)
*
- * It has been AutoGen-ed November 2, 2025 at 03:45:12 AM by AutoGen 5.18.16
+ * It has been AutoGen-ed February 18, 2026 at 03:56:38 PM by AutoGen 5.18.16
* From the definitions ntpq-opts.def
* and the template file options
*
@@ -93,9 +93,9 @@ typedef enum {
/** count of all options for ntpq */
#define OPTION_CT 17
/** ntpq version */
-#define NTPQ_VERSION "4.3.107"
+#define NTPQ_VERSION "4.3.108"
/** Full ntpq version text */
-#define NTPQ_FULL_VERSION "ntpq 4.3.107"
+#define NTPQ_FULL_VERSION "ntpq 4.3.108"
/**
* Interface defines for all options. Replace "n" with the UPPER_CASED
diff --git a/ntpq/ntpq.1ntpqman b/ntpq/ntpq.1ntpqman
index 92d52b9bd5..1d70a1c75b 100644
--- a/ntpq/ntpq.1ntpqman
+++ b/ntpq/ntpq.1ntpqman
@@ -10,11 +10,11 @@
.ds B-Font B
.ds I-Font I
.ds R-Font R
-.TH ntpq 1ntpqman "02 Nov 2025" "4.3.107" "User Commands"
+.TH ntpq 1ntpqman "18 Feb 2026" "4.3.108" "User Commands"
.\"
.\" EDIT THIS FILE WITH CAUTION (in-mem file)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:45:24 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:50 PM by AutoGen 5.18.16
.\" From the definitions ntpq-opts.def
.\" and the template file agman-cmd.tpl
.SH NAME
diff --git a/ntpq/ntpq.1ntpqmdoc b/ntpq/ntpq.1ntpqmdoc
index 879855393c..0880aec8f0 100644
--- a/ntpq/ntpq.1ntpqmdoc
+++ b/ntpq/ntpq.1ntpqmdoc
@@ -1,9 +1,9 @@
-.Dd November 2 2025
+.Dd February 18 2026
.Dt NTPQ 1ntpqmdoc User Commands
.Os
.\" EDIT THIS FILE WITH CAUTION (ntpq-opts.mdoc)
.\"
-.\" It has been AutoGen-ed November 2, 2025 at 03:45:20 AM by AutoGen 5.18.16
+.\" It has been AutoGen-ed February 18, 2026 at 03:56:46 PM by AutoGen 5.18.16
.\" From the definitions ntpq-opts.def
.\" and the template file agmdoc-cmd.tpl
.Sh NAME
diff --git a/ntpq/ntpq.html b/ntpq/ntpq.html
index f4f8c9bf4c..1f79cc6162 100644
--- a/ntpq/ntpq.html
+++ b/ntpq/ntpq.html
@@ -62,7 +62,7 @@ monitor the operational status
and determine the performance of
ntpd, the NTP daemon.
-This document applies to version 4.3.107 of ntpq.
+
This document applies to version 4.3.108 of ntpq.
diff --git a/ntpd/ntpd-opts.c b/ntpd/ntpd-opts.c
index 6cefc6b84c..2c2f403d99 100644
--- a/ntpd/ntpd-opts.c
+++ b/ntpd/ntpd-opts.c
@@ -1,7 +1,7 @@
/*
* EDIT THIS FILE WITH CAUTION (ntpd-opts.c)
*
- * It has been AutoGen-ed November 2, 2025 at 03:44:37 AM by AutoGen 5.18.16
+ * It has been AutoGen-ed February 18, 2026 at 03:55:27 PM by AutoGen 5.18.16
* From the definitions ntpd-opts.def
* and the template file options
*
@@ -80,7 +80,7 @@ extern FILE * option_usage_fp;
* static const strings for ntpd options
*/
static char const ntpd_opt_strs[3130] =
-/* 0 */ "ntpd 4.3.107\n"
+/* 0 */ "ntpd 4.3.108\n"
"Copyright (C) 1992-2025 The University of Delaware and Network Time Foundation, all rights reserved.\n"
"This is free software. It is licensed for use, modification and\n"
"redistribution under the terms of the NTP License, copies of which\n"
@@ -210,12 +210,12 @@ static char const ntpd_opt_strs[3130] =
/* 2900 */ "output version information and exit\0"
/* 2936 */ "version\0"
/* 2944 */ "NTPD\0"
/* 2949 */ "ntpd - NTP daemon program - Ver. 4.3.107\n"
"Usage: %s [ -
This document applies to version 4.3.107 of ntpd.
+
This document applies to version 4.3.108 of ntpd.
ntpd - NTP daemon program - Ver. 4.3.107
+ntpd - NTP daemon program - Ver. 4.3.108
Usage: ntpd [ -<flag> [<val>] | --<name>[{=| }<val>] ]... \
[ <server1> ... <serverN> ]
Flg Arg Option-Name Description
@@ -210,12 +210,12 @@ static char const ntpd_opt_strs[3130] =
/* 2936 */ "version\0"
/* 2944 */ "NTPD\0"
-/* 2949 */ "ntpd - NTP daemon program - Ver. 4.3.107\n"
+/* 2949 */ "ntpd - NTP daemon program - Ver. 4.3.108\n"
"Usage: %s [ -
This document applies to version 4.3.107 of ntpd.
diff --git a/ntpdc/ntpdc-opts.c b/ntpdc/ntpdc-opts.c
index 23dc7066ce..3850fa315d 100644
--- a/ntpdc/ntpdc-opts.c
+++ b/ntpdc/ntpdc-opts.c
@@ -1,7 +1,7 @@
/*
* EDIT THIS FILE WITH CAUTION (ntpdc-opts.c)
*
- * It has been AutoGen-ed November 2, 2025 at 03:45:03 AM by AutoGen 5.18.16
+ * It has been AutoGen-ed February 18, 2026 at 03:56:28 PM by AutoGen 5.18.16
* From the definitions ntpdc-opts.def
* and the template file options
*
@@ -74,7 +74,7 @@ extern FILE * option_usage_fp;
* static const strings for ntpdc options
*/
static char const ntpdc_opt_strs[2002] =
-/* 0 */ "ntpdc 4.3.107\n"
+/* 0 */ "ntpdc 4.3.108\n"
"Copyright (C) 1992-2025 The University of Delaware and Network Time Foundation, all rights reserved.\n"
"This is free software. It is licensed for use, modification and\n"
"redistribution under the terms of the NTP License, copies of which\n"
@@ -136,14 +136,14 @@ static char const ntpdc_opt_strs[2002] =
/* 1784 */ "no-load-opts\0"
/* 1797 */ "no\0"
/* 1800 */ "NTPDC\0"
/* 1806 */ "ntpdc - vendor-specific NTPD control program - Ver. 4.3.107\n"
"Usage: %s [ - [] | --[{=| }] ]... [ host ...]\n\0"
/* 1936 */ "$HOME\0"
/* 1942 */ ".\0"
/* 1944 */ ".ntprc\0"
/* 1951 */ "https://bugs.ntp.org, bugs@ntp.org\0"
/* 1986 */ "\n\0"
-/* 1988 */ "ntpdc 4.3.107";
+/* 1988 */ "ntpdc 4.3.108";
/**
* ipv4 option description with
@@ -828,7 +828,7 @@ static void bogus_function(void) {
translate option names.
*/
/* referenced via ntpdcOptions.pzCopyright */
- puts(_("ntpdc 4.3.107\n\
+ puts(_("ntpdc 4.3.108\n\
Copyright (C) 1992-2025 The University of Delaware and Network Time Foundation, all rights reserved.\n\
This is free software. It is licensed for use, modification and\n\
redistribution under the terms of the NTP License, copies of which\n\
@@ -897,14 +897,14 @@ implied warranty.\n"));
puts(_("load options from a config file"));
/* referenced via ntpdcOptions.pzUsageTitle */
- puts(_("ntpdc - vendor-specific NTPD control program - Ver. 4.3.107\n\
+ puts(_("ntpdc - vendor-specific NTPD control program - Ver. 4.3.108\n\
Usage: %s [ - [] | --[{=| }] ]... [ host ...]\n"));
/* referenced via ntpdcOptions.pzExplain */
puts(_("\n"));
/* referenced via ntpdcOptions.pzFullVersion */
- puts(_("ntpdc 4.3.107"));
+ puts(_("ntpdc 4.3.108"));
/* referenced via ntpdcOptions.pzFullUsage */
puts(_("<<>>"));
@@ -136,14 +136,14 @@ static char const ntpdc_opt_strs[2002] =
/* 1797 */ "no\0"
/* 1800 */ "NTPDC\0"
-/* 1806 */ "ntpdc - vendor-specific NTPD control program - Ver. 4.3.107\n"
+/* 1806 */ "ntpdc - vendor-specific NTPD control program - Ver. 4.3.108\n"
"Usage: %s [ - [] | --[{=| }] ]... [ host ...]\n\0"
/* 1936 */ "$HOME\0"
diff --git a/ntpq/ntpq-opts.c b/ntpq/ntpq-opts.c
index ab12069b3a..db1616bae4 100644
--- a/ntpq/ntpq-opts.c
+++ b/ntpq/ntpq-opts.c
@@ -1,7 +1,7 @@
/*
* EDIT THIS FILE WITH CAUTION (ntpq-opts.c)
*
- * It has been AutoGen-ed November 2, 2025 at 03:45:12 AM by AutoGen 5.18.16
+ * It has been AutoGen-ed February 18, 2026 at 03:56:38 PM by AutoGen 5.18.16
* From the definitions ntpq-opts.def
* and the template file options
*
@@ -74,7 +74,7 @@ extern FILE * option_usage_fp;
* static const strings for ntpq options
*/
static char const ntpq_opt_strs[2065] =
-/* 0 */ "ntpq 4.3.107\n"
+/* 0 */ "ntpq 4.3.108\n"
"Copyright (C) 1992-2025 The University of Delaware and Network Time Foundation, all rights reserved.\n"
"This is free software. It is licensed for use, modification and\n"
"redistribution under the terms of the NTP License, copies of which\n"
@@ -140,13 +140,13 @@ static char const ntpq_opt_strs[2065] =
/* 1857 */ "no-load-opts\0"
/* 1870 */ "no\0"
/* 1873 */ "NTPQ\0"
/* 1878 */ "ntpq - standard NTP query program - Ver. 4.3.107\n"
"Usage: %s [ - [] | --[{=| }] ]... [ host ...]\n\0"
/* 1997 */ "$HOME\0"
/* 2003 */ ".\0"
/* 2005 */ ".ntprc\0"
/* 2012 */ "https://bugs.ntp.org, bugs@ntp.org\0"
-/* 2047 */ "ntpq 4.3.107\0"
+/* 2047 */ "ntpq 4.3.108\0"
/* 2060 */ "hash";
/**
@@ -873,7 +873,7 @@ static void bogus_function(void) {
translate option names.
*/
/* referenced via ntpqOptions.pzCopyright */
- puts(_("ntpq 4.3.107\n\
+ puts(_("ntpq 4.3.108\n\
Copyright (C) 1992-2025 The University of Delaware and Network Time Foundation, all rights reserved.\n\
This is free software. It is licensed for use, modification and\n\
redistribution under the terms of the NTP License, copies of which\n\
@@ -945,11 +945,11 @@ implied warranty.\n"));
puts(_("load options from a config file"));
/* referenced via ntpqOptions.pzUsageTitle */
- puts(_("ntpq - standard NTP query program - Ver. 4.3.107\n\
+ puts(_("ntpq - standard NTP query program - Ver. 4.3.108\n\
Usage: %s [ - [] | --[{=| }] ]... [ host ...]\n"));
/* referenced via ntpqOptions.pzFullVersion */
- puts(_("ntpq 4.3.107"));
+ puts(_("ntpq 4.3.108"));
/* referenced via ntpqOptions.pzFullUsage */
puts(_("<<>>"));
@@ -140,13 +140,13 @@ static char const ntpq_opt_strs[2065] =
/* 1870 */ "no\0"
/* 1873 */ "NTPQ\0"
-/* 1878 */ "ntpq - standard NTP query program - Ver. 4.3.107\n"
+/* 1878 */ "ntpq - standard NTP query program - Ver. 4.3.108\n"
"Usage: %s [ - [] | --[{=| }] ]... [ host ...]\n\0"
/* 1997 */ "$HOME\0"